==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridGroupDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridGroupDescriptionsChangedEventArgsDescription } from "./GridGroupDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridGroupDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridGroupDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("GroupDescriptions", "Collection:ColumnGroupDescription:ColumnGroupDescriptionCollection:ColumnGroupDescription");
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridGroupDescriptionsChangedEventArgs", function () { return new GridGroupDescriptionsChangedEventArgsDescription(); });
        a.t("GridGroupDescriptionsChangedEventArgs", GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, 'GridGroupDescriptionsChangedEventArgsDescriptionMetadata');
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridGroupDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridGroupDescriptionsChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridGroupDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridGroupDescriptionsChangedEventArgsDescription } from "./GridGroupDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridGroupDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridGroupDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("GroupDescriptions", "Collection:ColumnGroupDescription:ColumnGroupDescriptionCollection:ColumnGroupDescription");
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridGroupDescriptionsChangedEventArgs", function () { return new GridGroupDescriptionsChangedEventArgsDescription(); });
        a.z("GridGroupDescriptionsChangedEventArgs", GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, 'GridGroupDescriptionsChangedEventArgsDescriptionMetadata');
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridGroupDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridGroupDescriptionsChangedEventArgsDescriptionMetadata };
